/**
 * Used for constructing and manipulating ranges.
 * @example String Construction
 *		new Range()
 *					.parse("{1-4, 6, 7}")
 *					.includes(4) // => true
 *
 * @example Manual Construction
 *    const range = new Range()
 *      range.ranges.push([0, 5])
 *      range.numbers.add(7)
 *
 */
export class NumberRange {
    /**
     * @type {Array<Error>}
     */
    errors: Array<Error>;
    /**
     * Ranges is an array of tuples. [0] is min, [1] is max.
     * @type {Array<[number, number]>}
     */
    ranges: Array<[number, number]>;
    /**
     * Possible single numbers
     * @type {Set<number>}
     */
    numbers: Set<number>;
    reset: () => void;
    /**
     * Checks if the parsed range includes the value.
     * @param {number} num
     */
    includes(num: number): boolean;
    /**
     * Given a string like this: "{1-3, 4, 5}" create a Range. Also accepts an array of numbers or a Set of numbers.
     * @param {Set<number> | Array<number> | string} str
     */
    parse(str: Set<number> | Array<number> | string): this;
}
